@@ -11,6 +11,11 @@
 
 plot.kstructure <- function(x, ...) {
 
+   ### check if package Rgraphviz is available
+   if (!require("Rgraphviz")) {
+     stop(sprintf("Plotting requires package 'Rgraphviz'."))
+   }
+
    ### check x
    if (!inherits(x, "kstructure")) {
       stop(sprintf("%s must be of class %s.", dQuote("x"), dQuote("kstructure")))
@@ -22,4 +27,4 @@ plot.kstructure <- function(x, ...) {
    ### plot results
    plot(relation(incidence=relmat, domain=x), ...)
 
-}
\ No newline at end of file
+}
